CHANGES
=======

* **202109**
    * 1.1.8 Post new release to https://pypi.lovelacelee.com 
    * 1.1.7 Tested local pypi server upload 
* **202108** Initial commit
    * 1.1.6 Sphinx doc system intergated, command lauch by setup.py 
    * 1.1.5 Bug fixed
    * 1.1.4 Add wrapper for SQLAlchemy https://www.osgeo.cn/sqlalchemy/ 
    * 1.1.3 Add ClslqMd5, only install pip.conf once
    * 1.1.2 Fixed a common use logger via pure python library
    * 1.1.1 Started with config paser support[json/xml/ini/yaml support]